==> xdelta3-gui_24.3.tar.xz: BUILD/translations/xdelta3-gui_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Create delta</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file
----------
start process</extracomment>
        <translation>Delta létrehozása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Create a binary difference between two files</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file</extracomment>
        <translation>Két bináris fájl közti különbségeket reprezentáló delta fájl létrehozása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Options</source>
        <extracomment>program options</extracomment>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Higher number = better compression ratio, but takes more time to finish</source>
        <translation>Nagy szám = Jobb tömörítés, de több időt vesz igénybe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Compression level</source>
        <extracomment>level of compression the delta file will use</extracomment>
        <translation>Tömörítési szint</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>More compression using various compression algorithms</source>
        <translation>További tömörítés különböző algoritmusok használatával</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Secondary compression</source>
        <extracomment>an extra layer of compression</extracomment>
        <translation>Másodlagos tömörítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <location filename="../mainwindow.ui" line="241"/>
        <source>File selection</source>
        <extracomment>area for selecting input and output files</extracomment>
        <translation>Fájl kiválasztás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>select target (new) file</source>
        <extracomment>select the new file from which to create a delta between it and the source.</extracomment>
        <translation>célfájl (új) kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Target file</source>
        <translation>Célfájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <source>Source file</source>
        <translation>Forrásfájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>Delta file name</source>
        <translation>Deltafájl neve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Select source file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Forrásfájl kiválasztása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>select source (old) file</source>
        <extracomment>select the original or source file</extracomment>
        <translation>forrásfájl (régi) kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Select target file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Célfájl kiválasztása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Change location...</source>
        <extracomment>starts a file chooser to select destination for output delta file</extracomment>
        <translation>Hely megváltoztatása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Apply delta</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file
----------
start the process</extracomment>
        <translation>Delta alkalmazása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Create a new file applying a delta (difference) file to an original file</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file</extracomment>
        <translation>Létrehoz egy új fájlt egy deltafájl (különbségfájl) alkalmazásával egy eredeti fájlra</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Input file</source>
        <extracomment>a file to start with as the source or input</extracomment>
        <translation>Bemeneti fájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>select input file</source>
        <extracomment>select the input or older file</extracomment>
        <translation>bemeneti fájl kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Select input file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Bemeneti fájl kiválasztása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Delta file</source>
        <extracomment>the delta or diff file between the input and the output</extracomment>
        <translation>Deltafájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>select delta</source>
        <extracomment>select the delta or patch file</extracomment>
        <translation>delta kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Select delta...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Delta kiválasztása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Output file</source>
        <extracomment>the final patched output file</extracomment>
        <translation>Kimeneti fájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>use default, or set up a custom name</source>
        <extracomment>create the new file name</extracomment>
        <translation>alapértelmezés használata, vagy egyedi név megadása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Change location..</source>
        <extracomment>starts a file chooser to select destination for output file</extracomment>
        <translation>Hely megváltoztatása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>ISO Files (*.iso);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>ISO fájlok (*.iso);;Minden fájl (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>ISO Files (*.xdelta3);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>ISO fájlok (*.xdelta3);;Minden fájl (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>Select file</source>
        <comment>choose a file</comment>
        <translation>Fájl kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="123"/>
        <source>Select directory to place the file in</source>
        <comment>select a target directory</comment>
        <translation>Válassza ki a könyvtárat a fájl elhelyezéséhez</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>Path not found</source>
        <comment>warning about not finding the target directory</comment>
        <translation>Útvonal nem található</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>Please select directory again.</source>
        <comment>message to try again</comment>
        <translation>Válassza ki újra a könyvtárat.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="196"/>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Please enter a name for the output file.</source>
        <translation>Adjon meg egy kimeneti fájl nevet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>File exists</source>
        <translation>A fájl már létezik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Output file exists, do you want to overwrite?</source>
        <comment>warning about overwritting an existing file</comment>
        <translation>A kimeneti fájl létezik, kívánja felülírni?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>Success</source>
        <comment>information that file was successfully written</comment>
        <translation>Sikeres</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>File was successfuly written to &apos;%1&apos; directory.</source>
        <comment>information that file was successfully written</comment>
        <translation>A fájl sikeresen kiírásra került a &apos;%1&apos; könyvtárba.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Took %1 to patch the file.</source>
        <comment>elapsed time, leave %1 untranslated</comment>
        <translation>A fájl foltozása %1 ideig tartott.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Error: Could not write the file.</source>
        <comment>information that there was an error creating the file</comment>
        <translation>Hiba: a fájl írása nem sikerült.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Please enter a name for the delta file.</source>
        <comment>name of delta file being created</comment>
        <translation>Adjon meg egy nevet a delta fájlnak.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>File not found</source>
        <comment>warning about file not found</comment>
        <translation>A fájl nem található</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>File &apos;%1&apos; found or not a file, please double-check the input.</source>
        <comment>warning about file not found</comment>
        <translation>A &apos;%1&apos; fájl nem található vagy nem fájl, ellenőrizze a bevitelt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>File exists</source>
        <comment>warning about overwritting file</comment>
        <translation>A fájl már létezik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>Delta file exists, do you want to overwrite?</source>
        <comment>warning about overwritting file</comment>
        <translation>A deltafájl már létezik, kívánja felülírni?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Success</source>
        <comment>information on file written succesfully</comment>
        <translation>Sikeres</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>File &apos;%1&apos; was successfuly written.</source>
        <comment>information on file written succesfully</comment>
        <translation>A &apos;%1&apos; fájl sikeresen kiírva.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Took %1 to create the patch.</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>A folt létrehozása %1 ideig tartott.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>Error: Could not write the file.</source>
        <comment>information that file was not written succsessfully</comment>
        <translation>Hiba: a fájl írása nem sikerült.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Cancel</source>
        <comment>stop an action in progress</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>%1 elapsed</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>%1 telt el</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>GUI for xdelta3 application.</source>
        <comment>short description for --help and desktop file</comment>
        <translation>Felület az xdelta3 programhoz.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>App for generating a binary difference between two files in the form of delta encoding</source>
        <comment>extra description for --help</comment>
        <translation>Alkalmazás két bináris fájl közötti különbségeket reprezentáló fájl létrehozásához, delta formátumban</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>file</source>
        <translation>fájl</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Name of the delta file</source>
        <translation>Deltafájl neve</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>[file]</source>
        <translation>[fájl]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program as normal user.</source>
        <comment>warning about running application as root</comment>
        <translation>Egyszerű felhasználóként kell futtatnia ezt a programot.</translation>
    </message>
</context>
</TS>

==> xdelta3-gui_26.01.3.tar.xz: BUILD/translations/xdelta3-gui_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Create delta</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file
----------
start process</extracomment>
        <translation>Delta létrehozása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Create a binary difference between two files</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file</extracomment>
        <translation>Két bináris fájl közti különbségeket reprezentáló delta fájl létrehozása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Options</source>
        <extracomment>program options</extracomment>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Higher number = better compression ratio, but takes more time to finish</source>
        <translation>Nagy szám = Jobb tömörítés, de több időt vesz igénybe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Compression level</source>
        <extracomment>level of compression the delta file will use</extracomment>
        <translation>Tömörítési szint</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>More compression using various compression algorithms</source>
        <translation>További tömörítés különböző algoritmusok használatával</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Secondary compression</source>
        <extracomment>an extra layer of compression</extracomment>
        <translation>Másodlagos tömörítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <location filename="../mainwindow.ui" line="241"/>
        <source>File selection</source>
        <extracomment>area for selecting input and output files</extracomment>
        <translation>Fájl kiválasztás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>select target (new) file</source>
        <extracomment>select the new file from which to create a delta between it and the source.</extracomment>
        <translation>célfájl (új) kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Target file</source>
        <translation>Célfájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <source>Source file</source>
        <translation>Forrásfájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>Delta file name</source>
        <translation>Deltafájl neve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Select source file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Forrásfájl kiválasztása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>select source (old) file</source>
        <extracomment>select the original or source file</extracomment>
        <translation>forrásfájl (régi) kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Select target file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Célfájl kiválasztása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Change location...</source>
        <extracomment>starts a file chooser to select destination for output delta file</extracomment>
        <translation>Hely megváltoztatása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Apply delta</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file
----------
start the process</extracomment>
        <translation>Delta alkalmazása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Create a new file applying a delta (difference) file to an original file</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file</extracomment>
        <translation>Létrehoz egy új fájlt egy deltafájl (különbségfájl) alkalmazásával egy eredeti fájlra</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Input file</source>
        <extracomment>a file to start with as the source or input</extracomment>
        <translation>Bemeneti fájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>select input file</source>
        <extracomment>select the input or older file</extracomment>
        <translation>bemeneti fájl kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Select input file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Bemeneti fájl kiválasztása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Delta file</source>
        <extracomment>the delta or diff file between the input and the output</extracomment>
        <translation>Deltafájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>select delta</source>
        <extracomment>select the delta or patch file</extracomment>
        <translation>delta kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Select delta...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Delta kiválasztása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Output file</source>
        <extracomment>the final patched output file</extracomment>
        <translation>Kimeneti fájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>use default, or set up a custom name</source>
        <extracomment>create the new file name</extracomment>
        <translation>alapértelmezés használata, vagy egyedi név megadása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Change location..</source>
        <extracomment>starts a file chooser to select destination for output file</extracomment>
        <translation>Hely megváltoztatása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>ISO Files (*.iso);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>ISO fájlok (*.iso);;Minden fájl (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>ISO Files (*.xdelta3);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>ISO fájlok (*.xdelta3);;Minden fájl (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>Select file</source>
        <comment>choose a file</comment>
        <translation>Fájl kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="123"/>
        <source>Select directory to place the file in</source>
        <comment>select a target directory</comment>
        <translation>Válassza ki a könyvtárat a fájl elhelyezéséhez</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>Path not found</source>
        <comment>warning about not finding the target directory</comment>
        <translation>Útvonal nem található</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>Please select directory again.</source>
        <comment>message to try again</comment>
        <translation>Válassza ki újra a könyvtárat.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="196"/>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Please enter a name for the output file.</source>
        <translation>Adjon meg egy kimeneti fájl nevet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>File exists</source>
        <translation>A fájl már létezik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Output file exists, do you want to overwrite?</source>
        <comment>warning about overwritting an existing file</comment>
        <translation>A kimeneti fájl létezik, kívánja felülírni?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>Success</source>
        <comment>information that file was successfully written</comment>
        <translation>Sikeres</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>File was successfuly written to &apos;%1&apos; directory.</source>
        <comment>information that file was successfully written</comment>
        <translation>A fájl sikeresen kiírásra került a &apos;%1&apos; könyvtárba.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Took %1 to patch the file.</source>
        <comment>elapsed time, leave %1 untranslated</comment>
        <translation>A fájl foltozása %1 ideig tartott.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Error: Could not write the file.</source>
        <comment>information that there was an error creating the file</comment>
        <translation>Hiba: a fájl írása nem sikerült.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Please enter a name for the delta file.</source>
        <comment>name of delta file being created</comment>
        <translation>Adjon meg egy nevet a delta fájlnak.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>File not found</source>
        <comment>warning about file not found</comment>
        <translation>A fájl nem található</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>File &apos;%1&apos; found or not a file, please double-check the input.</source>
        <comment>warning about file not found</comment>
        <translation>A &apos;%1&apos; fájl nem található vagy nem fájl, ellenőrizze a bevitelt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>File exists</source>
        <comment>warning about overwritting file</comment>
        <translation>A fájl már létezik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>Delta file exists, do you want to overwrite?</source>
        <comment>warning about overwritting file</comment>
        <translation>A deltafájl már létezik, kívánja felülírni?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Success</source>
        <comment>information on file written succesfully</comment>
        <translation>Sikeres</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>File &apos;%1&apos; was successfuly written.</source>
        <comment>information on file written succesfully</comment>
        <translation>A &apos;%1&apos; fájl sikeresen kiírva.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Took %1 to create the patch.</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>A folt létrehozása %1 ideig tartott.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>Error: Could not write the file.</source>
        <comment>information that file was not written succsessfully</comment>
        <translation>Hiba: a fájl írása nem sikerült.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Cancel</source>
        <comment>stop an action in progress</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>%1 elapsed</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>%1 telt el</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>GUI for xdelta3 application.</source>
        <comment>short description for --help and desktop file</comment>
        <translation>Felület az xdelta3 programhoz.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>App for generating a binary difference between two files in the form of delta encoding</source>
        <comment>extra description for --help</comment>
        <translation>Alkalmazás két bináris fájl közötti különbségeket reprezentáló fájl létrehozásához, delta formátumban</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>file</source>
        <translation>fájl</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Name of the delta file</source>
        <translation>Deltafájl neve</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>[file]</source>
        <translation>[fájl]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program as normal user.</source>
        <comment>warning about running application as root</comment>
        <translation>Egyszerű felhasználóként kell futtatnia ezt a programot.</translation>
    </message>
</context>
</TS>
